@@ -17,25 +17,26 @@ from configparser import ConfigParser
 from datetime import datetime, timezone
 from logging.config import fileConfig
 from subprocess import CalledProcessError
+from tempfile import mkstemp
 
 from botocore.config import Config
 from common.schedulers.slurm_commands import get_nodes_info
 from common.time_utils import seconds
-from common.utils import get_metadata, run_command, sleep_remaining_loop_time
+from common.utils import run_command, sleep_remaining_loop_time
 from retrying import retry
 from slurm_plugin.common import (
-    CONFIG_FILE_DIR,
     DEFAULT_COMMAND_TIMEOUT,
-    InstanceManager,
     expired_clustermgtd_heartbeat,
     get_clustermgtd_heartbeat,
     log_exception,
 )
+from slurm_plugin.slurm_resources import CONFIG_FILE_DIR
 
 LOOP_TIME = 60
 RELOAD_CONFIG_ITERATIONS = 10
 # Computemgtd config is under /opt/slurm/etc/pcluster/.slurm_plugin/; all compute nodes share a config
-COMPUTEMGTD_CONFIG_PATH = "/opt/slurm/etc/pcluster/.slurm_plugin/parallelcluster_computemgtd.conf"
+SLURM_PLUGIN_DIR = "/opt/slurm/etc/pcluster/.slurm_plugin"
+COMPUTEMGTD_CONFIG_PATH = f"{SLURM_PLUGIN_DIR}/parallelcluster_computemgtd.conf"
 log = logging.getLogger(__name__)
 
 
@@ -54,6 +55,7 @@ class ComputemgtdConfig:
     }
 
     def __init__(self, config_file_path):
+        _, self._local_config_file = mkstemp()
         self._get_config(config_file_path)
 
     def __repr__(self):
@@ -68,11 +70,11 @@ class ComputemgtdConfig:
         try:
             # Use subprocess based method to copy shared file to local to prevent hanging when NFS is down
             run_command(
-                f"cat {config_file_path} > {CONFIG_FILE_DIR}/.computemgtd_config.local",
+                f"cat {config_file_path} > {self._local_config_file}",
                 timeout=DEFAULT_COMMAND_TIMEOUT,
                 shell=True,  # nosec
             )
-            config.read_file(open(f"{CONFIG_FILE_DIR}/.computemgtd_config.local", "r"))
+            config.read_file(open(self._local_config_file, "r"))
         except Exception:
             log.error(f"Cannot read computemgtd configuration file: {config_file_path}")
             raise
@@ -121,17 +123,13 @@ class ComputemgtdConfig:
 
 
 @log_exception(log, "self terminating compute instance", catch_exception=CalledProcessError, raise_on_error=False)
-def _self_terminate(computemgtd_config):
+def _self_terminate():
     """Self terminate the instance."""
-    instance_manager = InstanceManager(
-        computemgtd_config.region, computemgtd_config.cluster_name, computemgtd_config.boto3_config
-    )
-    self_instance_id = get_metadata("instance-id")
     # Sleep for 10 seconds so termination log entries are uploaded to CW logs
-    log.info("Prepaing to self terminate the instance %s in 10 seconds!", self_instance_id)
+    log.info("Preparing to self terminate the instance in 10 seconds!")
     time.sleep(10)
-    log.info("Self terminating instance %s now!", self_instance_id)
-    instance_manager.delete_instances([self_instance_id], terminate_batch_size=1)
+    log.info("Self terminating instance now!")
+    run_command("sudo shutdown -h now")
 
 
 @retry(stop_max_attempt_number=3, wait_fixed=1500)
@@ -212,7 +210,7 @@ def _run_computemgtd():
             if computemgtd_config.disable_computemgtd_actions:
                 log.info("All computemgtd actions currently disabled")
             elif _is_self_node_down(computemgtd_config.nodename):
-                _self_terminate(computemgtd_config)
+                _self_terminate()
 
         sleep_remaining_loop_time(computemgtd_config.loop_time, current_time)
 
